package cn.com.infosec.jce.provider;

import cn.com.infosec.crypto.CipherKeyGenerator;
import cn.com.infosec.crypto.KeyGenerationParameters;
import cn.com.infosec.crypto.generators.DESKeyGenerator;
import cn.com.infosec.crypto.generators.DESedeKeyGenerator;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidParameterException;
import java.security.SecureRandom;
import java.security.spec.AlgorithmParameterSpec;
import javax.crypto.KeyGeneratorSpi;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;

public class JCEKeyGenerator extends KeyGeneratorSpi {
   protected String algName;
   protected int keySize;
   protected int defaultKeySize;
   protected CipherKeyGenerator engine;
   protected boolean uninitialised = true;

   protected JCEKeyGenerator(String algName, int defaultKeySize, CipherKeyGenerator engine) {
      this.algName = algName;
      this.defaultKeySize = defaultKeySize;
      this.keySize = defaultKeySize;
      this.engine = engine;
   }

   protected void engineInit(AlgorithmParameterSpec params, SecureRandom random) {
      throw new InvalidAlgorithmParameterException("Not Implemented");
   }

   protected void engineInit(SecureRandom random) {
      if (random != null) {
         this.engine.init(new KeyGenerationParameters(random, this.defaultKeySize));
         this.uninitialised = false;
      }

   }

   protected void engineInit(int keySize, SecureRandom random) {
      try {
         this.engine.init(new KeyGenerationParameters(random, keySize));
         this.uninitialised = false;
      } catch (IllegalArgumentException var3) {
         throw new InvalidParameterException(var3.getMessage());
      }
   }

   protected SecretKey engineGenerateKey() {
      if (this.uninitialised) {
         CipherKeyGenerator var10001 = this.engine;
         SecureRandom var1;
         var1 = new SecureRandom.<init>();
         var10001.init(new KeyGenerationParameters(var1, this.defaultKeySize));
         this.uninitialised = false;
      }

      JCEKeyGenerator var10002 = this;
      byte[] var2 = this.engine.generateKey();
      return new SecretKeySpec(var2, var10002.algName);
   }

   public static class Blowfish extends JCEKeyGenerator {
      public Blowfish() {
         Blowfish var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("Blowfish", 448, var1);
      }
   }

   public static class CAST6 extends JCEKeyGenerator {
      public CAST6() {
         CAST6 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("CAST6", 256, var1);
      }
   }

   public static class DES extends JCEKeyGenerator {
      public DES() {
         DES var10000 = this;
         DESKeyGenerator var1;
         var1 = new DESKeyGenerator.<init>();
         var10000.<init>("DES", 64, var1);
      }
   }

   public static class DESede extends JCEKeyGenerator {
      private boolean keySizeSet;

      public DESede() {
         DESede var10000 = this;
         DESede var10001 = this;
         DESedeKeyGenerator var1;
         var1 = new DESedeKeyGenerator.<init>();
         var10001.<init>("DESede", 192, var1);
         var10000.keySizeSet = false;
      }

      protected void engineInit(int keySize, SecureRandom random) {
         super.engineInit(keySize, random);
         this.keySizeSet = true;
      }

      protected SecretKey engineGenerateKey() {
         if (super.uninitialised) {
            CipherKeyGenerator var10001 = super.engine;
            SecureRandom var1;
            var1 = new SecureRandom.<init>();
            var10001.init(new KeyGenerationParameters(var1, super.defaultKeySize));
            super.uninitialised = false;
         }

         if (!this.keySizeSet) {
            byte[] var3;
            System.arraycopy(var3 = super.engine.generateKey(), 0, var3, 16, 8);
            return new SecretKeySpec(var3, super.algName);
         } else {
            DESede var10002 = this;
            byte[] var2 = super.engine.generateKey();
            return new SecretKeySpec(var2, var10002.algName);
         }
      }
   }

   public static class DESede3 extends JCEKeyGenerator {
      public DESede3() {
         DESede3 var10000 = this;
         DESedeKeyGenerator var1;
         var1 = new DESedeKeyGenerator.<init>();
         var10000.<init>("DESede3", 192, var1);
      }
   }

   public static class GOST28147 extends JCEKeyGenerator {
      public GOST28147() {
         GOST28147 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("GOST28147", 256, var1);
      }
   }

   public static class HC128 extends JCEKeyGenerator {
      public HC128() {
         HC128 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HC128", 128, var1);
      }
   }

   public static class HC256 extends JCEKeyGenerator {
      public HC256() {
         HC256 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HC256", 256, var1);
      }
   }

   public static class HMACSHA1 extends JCEKeyGenerator {
      public HMACSHA1() {
         HMACSHA1 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HMACSHA1", 160, var1);
      }
   }

   public static class HMACSHA224 extends JCEKeyGenerator {
      public HMACSHA224() {
         HMACSHA224 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HMACSHA224", 224, var1);
      }
   }

   public static class HMACSHA256 extends JCEKeyGenerator {
      public HMACSHA256() {
         HMACSHA256 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HMACSHA256", 256, var1);
      }
   }

   public static class HMACSHA384 extends JCEKeyGenerator {
      public HMACSHA384() {
         HMACSHA384 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HMACSHA384", 384, var1);
      }
   }

   public static class HMACSHA512 extends JCEKeyGenerator {
      public HMACSHA512() {
         HMACSHA512 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HMACSHA512", 512, var1);
      }
   }

   public static class HMACTIGER extends JCEKeyGenerator {
      public HMACTIGER() {
         HMACTIGER var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HMACTIGER", 192, var1);
      }
   }

   public static class IDEA extends JCEKeyGenerator {
      public IDEA() {
         IDEA var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("IDEA", 128, var1);
      }
   }

   public static class MD2HMAC extends JCEKeyGenerator {
      public MD2HMAC() {
         MD2HMAC var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HMACMD2", 128, var1);
      }
   }

   public static class MD4HMAC extends JCEKeyGenerator {
      public MD4HMAC() {
         MD4HMAC var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HMACMD4", 128, var1);
      }
   }

   public static class MD5HMAC extends JCEKeyGenerator {
      public MD5HMAC() {
         MD5HMAC var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HMACMD5", 128, var1);
      }
   }

   public static class RC2 extends JCEKeyGenerator {
      public RC2() {
         RC2 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("RC2", 128, var1);
      }
   }

   public static class RC4 extends JCEKeyGenerator {
      public RC4() {
         RC4 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("RC4", 128, var1);
      }
   }

   public static class RC5 extends JCEKeyGenerator {
      public RC5() {
         RC5 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("RC5", 128, var1);
      }
   }

   public static class RC564 extends JCEKeyGenerator {
      public RC564() {
         RC564 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("RC5-64", 256, var1);
      }
   }

   public static class RC6 extends JCEKeyGenerator {
      public RC6() {
         RC6 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("RC6", 256, var1);
      }
   }

   public static class RIPEMD128HMAC extends JCEKeyGenerator {
      public RIPEMD128HMAC() {
         RIPEMD128HMAC var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HMACRIPEMD128", 128, var1);
      }
   }

   public static class RIPEMD160HMAC extends JCEKeyGenerator {
      public RIPEMD160HMAC() {
         RIPEMD160HMAC var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("HMACRIPEMD160", 160, var1);
      }
   }

   public static class Rijndael extends JCEKeyGenerator {
      public Rijndael() {
         Rijndael var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("Rijndael", 192, var1);
      }
   }

   public static class Salsa20 extends JCEKeyGenerator {
      public Salsa20() {
         Salsa20 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("Salsa20", 128, var1);
      }
   }

   public static class Serpent extends JCEKeyGenerator {
      public Serpent() {
         Serpent var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("Serpent", 192, var1);
      }
   }

   public static class Skipjack extends JCEKeyGenerator {
      public Skipjack() {
         Skipjack var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("SKIPJACK", 80, var1);
      }
   }

   public static class TEA extends JCEKeyGenerator {
      public TEA() {
         TEA var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("TEA", 128, var1);
      }
   }

   public static class Twofish extends JCEKeyGenerator {
      public Twofish() {
         Twofish var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("Twofish", 256, var1);
      }
   }

   public static class VMPC extends JCEKeyGenerator {
      public VMPC() {
         VMPC var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("VMPC", 128, var1);
      }
   }

   public static class VMPCKSA3 extends JCEKeyGenerator {
      public VMPCKSA3() {
         VMPCKSA3 var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("VMPC-KSA3", 128, var1);
      }
   }

   public static class XTEA extends JCEKeyGenerator {
      public XTEA() {
         XTEA var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("XTEA", 128, var1);
      }
   }
}
